<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AptConfigMessage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="85"/>
        <source>Enter the number to configure: </source>
        <translation>请输入序号进行配置：</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="90"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>确 定</translation>
    </message>
</context>
<context>
    <name>BackendProcessPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="18"/>
        <source>Loading packages...</source>
        <translation>正在加载安装包…</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="19"/>
        <source>%1/%2 loaded</source>
        <translation>已加载%1/%2</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="22"/>
        <source>Initializing...</source>
        <translation>正在初始化…</translation>
    </message>
</context>
<context>
    <name>DdimErrorPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/ddimerrorpage.cpp" line="18"/>
        <source>OK</source>
        <translation>确 定</translation>
    </message>
</context>
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="118"/>
        <source>Package Installer</source>
        <translation>软件包安装器</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="128"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="695"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="819"/>
        <source>Installing other packages... Please open it later.</source>
        <translation>正在执行安装流程，无法打开</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="700"/>
        <source>Parsing failed: An illegal file structure was found in the manifest file!</source>
        <translation>软件包解析失败，软件包清单包含非法的文件结构！</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="702"/>
        <source>Parsing failed: An illegal version number was found in the manifest file!</source>
        <translation>软件包解析失败，软件包清单包含非法版本号！</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="704"/>
        <source>No deb packages found. Please check the folder.</source>
        <translation>未检测到安装包，请检查安装目录！</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="842"/>
        <source>The %1 package may be broken</source>
        <translation>请检查%1包是否损坏</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="851"/>
        <source>You can only install local %1 packages</source>
        <translation>只能安装本地的%1包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="860"/>
        <source>No permission to access this folder</source>
        <translation>没有权限访问文件夹</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="877"/>
        <source>Already Added</source>
        <translation>已添加</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="886"/>
        <source>%1 does not exist, please reselect</source>
        <translation>%1文件不存在，请重新选择文件</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="445"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="894"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="1047"/>
        <source>Bulk Install</source>
        <translation>批量安装</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="104"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="127"/>
        <source>Installation failed, please check your network connection</source>
        <translation>安装失败，请检查您的网络连接</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="108"/>
        <source>Installation failed, please check for updates in Control Center</source>
        <translation>安装失败，请在控制中心检查更新</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="111"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="117"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="133"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>安装失败，磁盘空间不足</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="139"/>
        <source>No digital signature</source>
        <translation>无数字签名</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="144"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="895"/>
        <source>Invalid digital signature</source>
        <translation>数字签名无效</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="152"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="880"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1981"/>
        <source>The administrator has set policies to prevent installation of this package</source>
        <translation>管理员已限制，该软件禁止安装</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="159"/>
        <source>Installation Failed</source>
        <translation>安装失败</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="863"/>
        <source>current system</source>
        <translation>当前系统环境</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="866"/>
        <source>%2 has been installed in %1, please uninstall this package before installing it</source>
        <translation>已在%1中安装%2，请先卸载后再安装此包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="873"/>
        <source>Broken dependencies, try installing the app in compatibility mode</source>
        <translation>依赖关系不满足，请尝试使用兼容模式安装该应用</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="876"/>
        <source>Compatibility mode installation failed</source>
        <translation>兼容模式安装失败</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="898"/>
        <source>Failed to install %1</source>
        <translation>%1安装失败</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1328"/>
        <source>Unable to install - no digital signature</source>
        <translation>无法安装，安装包无数字签名</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1329"/>
        <source>Please go to Control Center to enable developer mode and try again. Proceed?</source>
        <translation>请进入控制中心，开启开发者模式后，再尝试继续安装。是否前往？</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1332"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1333"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>前 往</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1280"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1394"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1983"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>确 定</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1284"/>
        <source>Failed to install %1: no valid digital signature</source>
        <translation>无法安装%1，安装包无有效的数字签名</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1435"/>
        <source>This package does not have a valid digital signature. Continue with the installation?</source>
        <translation>此安装包没有有效的数字签名，是否继续安装？</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1437"/>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1438"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>继续</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1278"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1391"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1980"/>
        <source>Unable to install</source>
        <translation>无法安装</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1392"/>
        <source>This package does not have a valid digital signature</source>
        <translation>此安装包没有有效的数字签名</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="902"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="908"/>
        <source>Broken dependencies: %1</source>
        <translation>依赖关系不满足：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="149"/>
        <source>Authentication failed</source>
        <translation>配置授权失败</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="834"/>
        <source>Unmatched package architecture</source>
        <translation>软件包架构不匹配</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="51"/>
        <source>Drag deb packages here</source>
        <translation>拖拽软件包到此</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="93"/>
        <source>Select File</source>
        <translation>选择文件</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="35"/>
        <source>Show details</source>
        <translation>显示详细信息</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="35"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>收 起</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="179"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>安 装</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="180"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>完 成</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="182"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>返 回</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="545"/>
        <source>Install %1 will remove: </source>
        <translation>安装%1将会卸载：</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="563"/>
        <source>Dependencies in the repository</source>
        <translation>仓库中存在的依赖包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="570"/>
        <source>Missing dependencies</source>
        <translation>仓库中缺失的依赖包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="629"/>
        <source>Installing dependencies: %1</source>
        <translation>正在安装依赖：%1</translation>
    </message>
</context>
<context>
    <name>PackageSelectItem</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="87"/>
        <source>Same version installed</source>
        <translation>已安装相同版本</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="91"/>
        <source>Earlier version installed: %1</source>
        <translation>已安装较早的版本：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="96"/>
        <source>Later version installed: %1</source>
        <translation>已安装较新的版本：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="102"/>
        <source>Unmatched package architecture</source>
        <translation>软件包架构不匹配</translation>
    </message>
</context>
<context>
    <name>PackageSelectView</name>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="23"/>
        <source>Select all</source>
        <translation>全选</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="24"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>安 装</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="62"/>
        <source>Installing</source>
        <translation>正在安装</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="66"/>
        <source>Installed</source>
        <translation>已安装</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="74"/>
        <source>Failed</source>
        <translation>安装失败</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="70"/>
        <source>Waiting</source>
        <translation>等待安装</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="246"/>
        <source>Same version installed</source>
        <translation>已安装相同版本</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="248"/>
        <source>Later version installed: %1</source>
        <translation>已安装较新的版本：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="250"/>
        <source>Earlier version installed: %1</source>
        <translation>已安装较早的版本：%1</translation>
    </message>
</context>
<context>
    <name>PackagesListView</name>
    <message>
        <location filename="../src/deb-installer/model/packagelistview.cpp" line="189"/>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="32"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="50"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="52"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>收 起</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="9"/>
        <source>Basic</source>
        <translation>基础设置</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="10"/>
        <source>Check digital signatures if the developer mode is enabled</source>
        <translation>开发者模式下，检测安装包的签名</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="88"/>
        <source>To install unsigned apps, go to Security Center &gt; Tools &gt; App Security, and select the app types that can be installed.</source>
        <translation>如需安装未签名应用，前往安全中心-安全工具-应用安全设置允许安装的应用类型。</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="90"/>
        <source>Security Center &gt; Tools &gt; App Security</source>
        <translation>安全中心-安全工具-应用安全</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/uab/uab_package.cpp" line="54"/>
        <source>The system has not installed Linglong environment, please install it first</source>
        <translation>系统无玲珑环境，请先安装</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="47"/>
        <source>Unable to install</source>
        <translation>无法安装</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="49"/>
        <source>This package does not have a valid digital signature and has been blocked from installing/running. Go to Security Center &gt; Tools &gt; App Security to change the settings.</source>
        <translation>安装包没有有效的数字签名，已被禁止安装/运行，请前往安全中心-安全工具-应用安全进行调整。</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="52"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="53"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>前 往</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="282"/>
        <source>Will remove: </source>
        <translation>将会卸载：</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1035"/>
        <source>Collapse</source>
        <translation>收起</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="519"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1233"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1438"/>
        <source>Reinstall</source>
        <translation>重新安装</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1238"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1443"/>
        <source>Later version installed: %1</source>
        <translation>已安装较新的版本：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1239"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1444"/>
        <source>Downgrade</source>
        <translation>安装旧版本</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1244"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1449"/>
        <source>Earlier version installed: %1</source>
        <translation>已安装较早的版本：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1336"/>
        <source>Installing dependencies: %1</source>
        <translation>正在安装依赖：%1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1499"/>
        <source>Failed to install %1</source>
        <translation>%1安装失败</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="244"/>
        <source>Version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="190"/>
        <source>Select a compatibility mode:</source>
        <translation>选择兼容模式：</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="511"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>安 装</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="515"/>
        <source>Remove</source>
        <comment>button</comment>
        <translation>卸 载</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="523"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>确 定</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="527"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>返 回</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="531"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>完 成</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="777"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="818"/>
        <source>Trying to install %2 in %1 compatibility mode</source>
        <translation>正在尝试使用%1兼容模式安装%2</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="858"/>
        <source>Uninstalling %2 from %1 compatibility mode</source>
        <translation>正在从%1兼容模式卸载%2</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="987"/>
        <source>%2 was successfully installed to %1 compatibility mode</source>
        <translation>%2已成功安装到%1兼容模式</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="991"/>
        <source>Installed successfully</source>
        <translation>安装成功</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1000"/>
        <source>%2 has been successfully uninstalled from %1 compatibility mode</source>
        <translation>%2已从%1兼容模式成功卸载</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1004"/>
        <source>Uninstalled successfully</source>
        <translation>卸载成功</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1024"/>
        <source>Uninstall Failed</source>
        <translation>卸载失败</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1070"/>
        <source>Install %1 will remove: </source>
        <translation>安装%1将会卸载：</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1091"/>
        <source>Dependencies in the repository</source>
        <translation>仓库中存在的依赖包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1098"/>
        <source>Missing dependencies</source>
        <translation>仓库中缺失的依赖包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1245"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1450"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>更 新</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1505"/>
        <source>Invalid digital signature</source>
        <translation>数字签名无效</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="232"/>
        <source>Name: </source>
        <translation>名称：</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1232"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1437"/>
        <source>Same version installed</source>
        <translation>已安装相同版本</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Install</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="50"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="762"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="803"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="984"/>
        <source>Show details</source>
        <translation>显示详细信息</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="32"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="51"/>
        <source>Show dependencies</source>
        <translation>显示依赖包关系</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Uninstall</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="843"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="997"/>
        <source>Show details</source>
        <translation>显示卸载进程</translation>
    </message>
</context>
<context>
    <name>Uab::UabPackageListModel</name>
    <message>
        <location filename="../src/deb-installer/uab/uab_package_list_model.cpp" line="557"/>
        <source>Installation Failed</source>
        <translation>安装失败</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="17"/>
        <source>Show related packages</source>
        <translation>显示相关软件包</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="17"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>收 起</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="39"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="41"/>
        <source>Confirm</source>
        <translation>确定卸载</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="131"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation>您确定要卸载%1 吗？
所有依赖也会被一起移除</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="133"/>
        <source>Are you sure you want to uninstall %1?
The system or other applications may not work properly</source>
        <translation>您确定要卸载%1吗？
卸载此软件可能会导致系统或其他软件无法正常使用</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="177"/>
        <source>Are you sure you want to uninstall %2 
from %1 compatibility mode?</source>
        <translation>您确定要从%1兼容模式
卸载%2吗？</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="48"/>
        <location filename="../src/deb-installer/main.cpp" line="49"/>
        <source>Package Installer</source>
        <translation>软件包安装器</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="50"/>
        <source>Package Installer helps users install and remove local packages, and supports bulk installation.</source>
        <translation>软件包安装器用于帮助用户安装和卸载本地软件，支持批量安装。</translation>
    </message>
</context>
</TS>
